=======
History
=======

0.2.8 (2021-09-30)
-------------------------

* Add to_json() method to KGroup, enabling Kleio to JSon serialization.


0.2.7 (2021-08-29)
------------------

* Auto build on Travis, with release to pypi
* Skeleton docs on readthedocs

0.1.0 (2021-07-09)
------------------

* First release on PyPI.
